==> icradius-0.10-pre1.tar.gz: icradius-0.10-pre1/scripts/acctexport.pl <==
#!/usr/bin/perl -T
########################################################################
#                                                                      #
#    userimport.pl                InnerCite                            #
#                                 Mike Machado <mike@innercite.com>    #
#                                 27 April 1999                        #
#                                                                      #
#    Imports standard RADIUS users file into mysql                     #
#                                                                      #
#                   Copyright under same terms as Cistron RADIUS       #
#                                                                      #
########################################################################


use DBI;
use strict;


my $sth;
my $sth1;
my $dbusername = 'root';
my $dbpassword = 'rootpass';

my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword);


$sth = $dbh->prepare("SELECT * FROM radacct");
$sth->execute;
while (my @acct = $sth->fetchrow_array) {

   $sth1 = $dbh->prepare("SELECT DATE_FORMAT\(\"$acct[7]\",\"%a %b %e %T %Y\"\)");
   $sth1->execute;
   my $date = $sth1->fetchrow_array;

   print "$date\n";
   print "\tAcct-Session-Id = \"$acct[1]\"\n";
   print "\tUser-Name = \"$acct[2]\"\n";
   print "\tNAS-IP-Address = $acct[4]\n";
   print "\tNAS-Port = $acct[5]\n";
   print "\tNAS-Port-Type = $acct[6]\n";
   print "\tAcct-Status-Type = Start\n";
   print "\tAcct-Authentic = $acct[10]\n";
   print "\tConnect-Info = \"$acct[11]\"\n" if $acct[11] ne '';
   print "\tCalled-Station-Id = \"$acct[14]\"\n" if $acct[14] ne '';
   print "\tCalling-Station-Id = \"$acct[15]\"\n" if $acct[15] ne '';
   print "\tService-Type = $acct[17]\n";
   print "\tFramed-Protocol = $acct[18]\n";
   print "\tFramed-IP-Address = $acct[19]\n";
   print "\tAcct-Delay-Time = 0\n";

   print "\n";
   if ($acct[8] ne '0000-00-00 00:00:00') {
      $sth1 = $dbh->prepare("SELECT DATE_FORMAT\(\"$acct[8]\",\"%a %b %e %T %Y\"\)");
      $sth1->execute;
      my $date = $sth1->fetchrow_array;

      print "$date\n";
      print "\tAcct-Session-Id = \"$acct[1]\"\n";
      print "\tUser-Name = \"$acct[2]\"\n";
      print "\tNAS-IP-Address = $acct[4]\n";
      print "\tNAS-Port = $acct[5]\n";
      print "\tNAS-Port-Type = $acct[6]\n";
      print "\tAcct-Status-Type = Stop\n";
      print "\tAcct-Session-Time = $acct[9]\n";
      print "\tAcct-Authentic = $acct[10]\n";
      print "\tConnect-Info = \"$acct[11]\"\n" if $acct[11] ne '';
      print "\tAcct-Input-Octets = $acct[12]\n";
      print "\tAcct-Output-Octets = $acct[13]\n";
      print "\tCalled-Station-Id = \"$acct[14]\"\n" if $acct[14] ne '';
      print "\tCalling-Station-Id = \"$acct[15]\"\n" if $acct[15] ne '';
      print "\tAcct-Termincate-Cause = $acct[16]\n";
      print "\tService-Type = $acct[17]\n";
      print "\tFramed-Protocol = $acct[18]\n";
      print "\tFramed-IP-Address = $acct[19]\n";
      print "\tAcct-Delay-Time = 0\n";

      print "\n";
   }


}
 
$sth1->finish;
$sth->finish;
$dbh->disconnect;

==> icradius-0.14.tar.gz: icradius-0.14/scripts/acctexport.pl <==
#!/usr/bin/perl -T
########################################################################
#                                                                      #
#    acctexport.pl                InnerCite                            #
#                                 Mike Machado <mike@innercite.com>    #
#                                 27 April 1999                        #
#                                                                      #
#    Exports standard RADIUS detail files from ICRADIUS                #
#                                                                      #
#                   Copyright under same terms as Cistron RADIUS       #
#                                                                      #
########################################################################


use DBI;
use strict;


my $sth;
my $sth1;
my $dbusername = 'root';
my $dbpassword = 'rootpass';

my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword);


$sth = $dbh->prepare("SELECT * FROM radacct");
$sth->execute;
while (my @acct = $sth->fetchrow_array) {

   $sth1 = $dbh->prepare("SELECT DATE_FORMAT\(\"$acct[7]\",\"%a %b %e %T %Y\"\)");
   $sth1->execute;
   my $date = $sth1->fetchrow_array;

   print "$date\n";
   print "\tAcct-Session-Id = \"$acct[1]\"\n";
   print "\tUser-Name = \"$acct[2]\"\n";
   print "\tNAS-IP-Address = $acct[4]\n";
   print "\tNAS-Port-Id = $acct[5]\n";
   print "\tNAS-Port-Type = $acct[6]\n";
   print "\tAcct-Status-Type = Start\n";
   print "\tAcct-Authentic = $acct[10]\n";
   print "\tConnect-Info = \"$acct[11]\"\n" if $acct[11] ne '';
   print "\tCalled-Station-Id = \"$acct[14]\"\n" if $acct[14] ne '';
   print "\tCalling-Station-Id = \"$acct[15]\"\n" if $acct[15] ne '';
   print "\tService-Type = $acct[17]\n";
   print "\tFramed-Protocol = $acct[18]\n";
   print "\tFramed-IP-Address = $acct[19]\n";
## its always delay 0 because we account for the delay when we get the record in the first place
   print "\tAcct-Delay-Time = 0\n";

   print "\n";

   ### If this is a record and we have not got the stop yet do not print anything for the stop record
   if ($acct[8] ne '0000-00-00 00:00:00') {
      $sth1 = $dbh->prepare("SELECT DATE_FORMAT\(\"$acct[8]\",\"%a %b %e %T %Y\"\)");
      $sth1->execute;
      my $date = $sth1->fetchrow_array;

      print "$date\n";
      print "\tAcct-Session-Id = \"$acct[1]\"\n";
      print "\tUser-Name = \"$acct[2]\"\n";
      print "\tNAS-IP-Address = $acct[4]\n";
      print "\tNAS-Port-Id = $acct[5]\n";
      print "\tNAS-Port-Type = $acct[6]\n";
      print "\tAcct-Status-Type = Stop\n";
      print "\tAcct-Session-Time = $acct[9]\n";
      print "\tAcct-Authentic = $acct[10]\n";
      print "\tConnect-Info = \"$acct[11]\"\n" if $acct[11] ne '';
      print "\tAcct-Input-Octets = $acct[12]\n";
      print "\tAcct-Output-Octets = $acct[13]\n";
      print "\tCalled-Station-Id = \"$acct[14]\"\n" if $acct[14] ne '';
      print "\tCalling-Station-Id = \"$acct[15]\"\n" if $acct[15] ne '';
      print "\tAcct-Terminate-Cause = $acct[16]\n";
      print "\tService-Type = $acct[17]\n";
      print "\tFramed-Protocol = $acct[18]\n";
      print "\tFramed-IP-Address = $acct[19]\n";
      print "\tAcct-Delay-Time = 0\n";

      print "\n";
   }


}
 
$sth1->finish;
$sth->finish;
$dbh->disconnect;
